@@ -11,11 +11,18 @@ from graphmanagerlib.JsonManager import ConvertJsonToDocumentsObjects
 bpemb_en = BPEmb(lang="fra", dim=100)
 sent_model = SentenceTransformer('distilbert-base-nli-stsb-mean-tokens')
 
+def make_bert_features_if_required(text):
+    if(text == 'NaN'):
+        return nan_features
+    else:
+        return make_sent_bert_features(text)
 
 def make_sent_bert_features(text):
     emb = sent_model.encode([text])[0]
     return emb
 
+nan_features = make_sent_bert_features('NaN')
+
 
 def get_data(documents,tags):
     """
@@ -67,8 +74,9 @@ def makeIndividualData(file,tags):
     numeric_features = df[feature_cols].values.astype(np.float32)
     features = np.concatenate((numeric_features, text_features), axis=1)
 
+
     for val in ['right_text', 'left_text', 'top_text', 'bottom_text']:
-        text_features = np.array(df[val].map(make_sent_bert_features).tolist()).astype(np.float32)
+        text_features = np.array(df[val].map(make_bert_features_if_required).tolist()).astype(np.float32)
         features = np.concatenate((features, text_features), axis=1)
 
     features = torch.tensor(features)
