@@ -12,7 +12,7 @@ class GraphManager:
 
     def _getTagsList(self, tagsPath):
         tags = []
-        with open(tagsPath, newline='') as inputfile:
+        with open(tagsPath, newline='', encoding="utf-8-sig") as inputfile:
             for row in csv.reader(inputfile):
                 tags.append(row[0])
         return tags
