@@ -3,7 +3,7 @@ from graphmanagerlib.Node import Node
 from graphmanagerlib.Document import Document
 
 def GetJsonFromFile(jsonPath):
-    with open(jsonPath, encoding="utf8") as file:
+    with open(jsonPath, encoding="utf-8-sig") as file:
         reader = json.load(file)
         return reader
 
